/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by 
 *  Björnsen Beratende Ingenieure GmbH 
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.sinfo.flowdepth;

import java.io.Serializable;

/**
 * Part of {@link FlowDepthCalculationResult} which represents one calculated row of flow depth data.
 * 
 * @author Gernot Belger
 */
final class FlowDepthRow
implements Serializable {
	private final double station;
	private final double flowDepth;
	private final double flowDepthWithTkh;
	private final double tkh;
	private final double waterlevel;
	private final double discharge;
	private final String waterlevelLabel;
	private final String gauge;
	private final double meanBedHeight;
	private final String soundageLabel;
	private final String location;

	public FlowDepthRow( double station, double flowDepth, double flowDepthWithTkh, double tkh, double waterlevel, double discharge, String waterlevelLabel, String gauge, double meanBedHeight, String soundageLabel, String location ) {
		this.station = station;
		this.flowDepth = flowDepth;
		this.flowDepthWithTkh = flowDepthWithTkh;
		this.tkh = tkh;
		this.waterlevel = waterlevel;
		this.discharge = discharge;
		this.waterlevelLabel = waterlevelLabel;
		this.gauge = gauge;
		this.meanBedHeight = meanBedHeight;
		this.soundageLabel = soundageLabel;
		this.location = location;
	}

	public double getStation() {
		return station;
	}

	public double getFlowDepth() {
		return flowDepth;
	}

	public double getFlowDepthWithTkh() {
		return flowDepthWithTkh;
	}
	
	public double getTkh() {
		return tkh;
	}

	public double getWaterlevel() {
		return waterlevel;
	}

	public double getDischarge() {
		return discharge;
	}

	public String getWaterlevelLabel() {
		return waterlevelLabel;
	}

	public String getGauge() {
		return gauge;
	}

	public double getMeanBedHeight() {
		return meanBedHeight;
	}

	public String getSoundageLabel() {
		return soundageLabel;
	}

	public String getLocation() {
		return location;
	}
}